<?php
/**
*
* PALP - PHP Altitude Log Parser
* @palp.php
* @copyright (c) 2010 Jared Orzechowski - jaredo AT ameritech DOT net
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

# Include palp config settings
require_once('palp.inc');

# Disable php notices unless debug enabled
if (!$GLOBALS['debug']) { error_reporting(E_ALL ^ E_NOTICE); }

//======================== JSON Functions ===========================

// If php prior to 5.1 use PEAR library
if (!function_exists('json_decode')) {
	function json_decode($content, $assoc=false) {
        	require_once 'Services/JSON.php';
                if ($assoc) {
                	$json = new Services_JSON(SERVICES_JSON_LOOSE_TYPE);
	        } else {
                	$json = new Services_JSON;
                }
	return $json->decode($content);
	}
}

if (!function_exists('json_encode')) {
	function json_encode($content) {
        	require_once 'Services/JSON.php';
        	$json = new Services_JSON;
               
		return $json->encode($content);
	}
}

// Functions to remove JSON trailing commas and add utf8 encoding
function mjson_decode($json) {
	return json_decode(removeTrailingCommas(utf8_encode($json)));
}
   
function removeTrailingCommas($json) {
       	$json=preg_replace('/,\s*([\]}])/m', '$1', $json);
       	return $json;
}

function is_odd($num) {
 return $num % 2 == 0 ? false:true;
}

// Time functions
function duration($secs) {
	$vals = array('w' => (int) ($secs / 86400 / 7),
		'd' => $secs / 86400 % 7,
		'h' => $secs / 3600 % 24,
		'm' => $secs / 60 % 60,
		's' => $secs % 60);

	$ret = array();

	$added = false;

	foreach ($vals as $k => $v) {
	
		if ($v > 0 || $added) {
			$added = true;
			$ret[] = $v . $k;
		}
		
	}
 
	return join(' ', $ret);
} 

//========================= Type Functions ==========================	

// Start serverInit function
function parse_serverinit($obj) {
	# Debug output
	if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " serverInit \n"; }

	# Check if server is already in server status DB
	$sql = "	
		SELECT 
			* 
		FROM 
			server_status 
		WHERE 
			port = '" .$obj->port. "'
	";
        
	# Result
	$num_rows = mysql_num_rows(mysql_query($sql));
	
	if ($num_rows) {
	
		# Server exists in DB, update server
		$sql = "
			UPDATE 
				server_status 
			SET 
				port='" .$obj->port. "',
				name='" .mysql_real_escape_string($obj->name). "',
				maxplayers='" .$obj->maxPlayerCount. "' 
			WHERE 
				port='" .$obj->port. "' 
			LIMIT 1
		";

	} else {
		
		# No server entry in DB, add new entry 
		$sql = "
			INSERT INTO 
				server_status 
				(id,
				port, 
				name,
				maxplayers) 
			VALUES 
				('',
				'" .$obj->port. "',
				'" .mysql_real_escape_string($obj->name). "',
				'" .($obj->maxPlayerCount). "')
		";
	}

	# Execute query
	$result = mysql_query($sql);
}
// End serverInit function

// Start mapChange function
function parse_mapchange($obj) {

	# Debug output
	if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " mapChange to " .$obj->map. "\n"; }

	# Check is server is already in DB 
	$sql = "
		SELECT 
			* 
		FROM 
			server_status 
		WHERE 
			port = '" .$obj->port. "'
	";

	# Result
	$num_rows = mysql_num_rows(mysql_query($sql));

	if ($num_rows) {

		# Server exists in DB, update query
		$sql = "
			UPDATE 
				server_status 
			SET 
				time='" .time(). "', 
				port='" .$obj->port. "',
				map='" .mysql_real_escape_string($obj->map). "',
				mode='" .$obj->mode. "' 
			WHERE 
				port='" .$obj->port. "' 
			LIMIT 1
		";

	} else {
	
		# No server entry, most likely PALP was started after serverInit - you should reload while PALP is running
		$sql = "
			INSERT INTO 
				server_status 
				(id, 
				time, 
				port, 
				tournament) 
			VALUES 
				('',
				'" .$obj->time. "',
				'" .$obj->port. "',
				'0')
		";
	}

	# Erocess query
	$result = mysql_query($sql);	

	// Reset live player scores on mapchange

	# Debug output
	if ($GLOBALS['debug']) { echo "PALP: Resetting " .$obj->port. " player stats\n"; }

	# Query current server players
	$sql = "
		SELECT 
			* 
		FROM 
			server_players 
		WHERE 
			p_port = '" .$obj->port. "'
	";

	$query = mysql_query($sql);	

	# Result
	$num_rows = mysql_num_rows($query);
	
	if ($num_rows) {
		
		# Loop through current players, reset live stats
		while ($row = mysql_fetch_assoc($query)) {
			
			$sql = "
				UPDATE 
					server_players 
				SET 
					p_kills='0',
					p_deaths='0',
					p_assists='0',
					p_goals='0',
					p_crashes='0',
					p_streak='0',
					p_structuredamage='0',
					p_team='2' 
				WHERE 
					p_port='" .$obj->port. "' 
				AND 
					p_id='" .$row['p_id']. "'
			";

			# Execute query
			$result = mysql_query($sql);
                }
	}
	
	# If no players, do nothing	
}
// End mapChange function

// Start clientAdd function
function parse_clientadd($obj) {
        
	$sql ="
		SELECT 
			* 
		FROM 
			server_players 
		WHERE 
			p_port = '" .$obj->port. "'
		AND
			p_vaporid = '" .$obj->vaporId. "' 
		
		LIMIT 1
	";

	# Result
        $num_rows = mysql_num_rows(mysql_query($sql));

        # Found a stale user - wtf you cant be joining if I already think you're here!
        if ($num_rows) {
                
		$sql = "
			DELETE FROM 
				server_players 
			WHERE 
				p_port='" .$obj->port. "'
			AND
				p_vaporid='" .$obj->vaporId. "'
			LIMIT 1
		";

		# Execute query
		$result = mysql_query($sql);
        } 

	# Add player to live database if vaporid is not a bot vaporid
	if ($obj->vaporId != "00000000-0000-0000-0000-000000000000") {
		
		# Debug output
		if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " clientAdd " .$obj->nickname. "\n"; }
	
		# Send user the current MOTD
		send_command("$obj->port,console,serverWhisper \"" . addslashes($obj->nickname) . "\" " .$GLOBALS['motd']. "");
		
		$sql = "
			INSERT INTO
			server_players 
				(id,
				p_time,
				p_port,
				p_id,
				p_nickname,
				p_vaporid,
				p_ip,
				p_kills,
				p_deaths,
				p_assists,
				p_goals,
				p_crashes,
				p_team,
				p_streak,
				p_structuredamage,
				s_kills,
				s_deaths,
				s_assists,
				s_goals,
				s_crashes,
				s_structuredamage)
			VALUES 
				('',
				'" .time(). "',
				'" .$obj->port. "',
				'" .$obj->player. "',
				'" .mysql_real_escape_string($obj->nickname). "',
				'" .$obj->vaporId. "',
				'" .strstr($obj->ip, ':', true). "',
				'0',
				'0',
				'0',
				'0',
				'0',
				'2',
				'0',
				'0',
                                '0',
                                '0',
                                '0',
                                '0',
                                '0',
                                '0')
		";

	$result = mysql_query($sql);
	
	if (!$result) { die('Invalid query: ' . mysql_error()); }

	}
}
// End clientAdd function

// Start clientRemove function
function parse_clientremove($obj) {
	
	# Debug output
	if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " clientRemove " .$obj->nickname. "\n"; }

	# Delete user from server based on vaporid
	$sql = "
		DELETE FROM
			 server_players 
		WHERE
			p_port='" .$obj->port. "'
		AND 
			p_vaporid='" .$obj->vaporId. "'
		LIMIT 1
	";
       
	# Execute query 
	$result = mysql_query($sql);

}
// End clientRemove function

// Start pingSummary function
function parse_pingsummary($obj) {

	# Debug output
	if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " pings \n"; }

	# Loop through player pingsummary, update each players ping
	foreach($obj->pingByPlayer as $id => $ping) {
		$sql = "
			UPDATE 
				server_players 
			SET 
				p_ping='" .$ping. "' 
			WHERE 
				p_port='" .$obj->port. "' 
			AND 
				p_id='" .$id. "' 
			LIMIT 1
		";
		
		# Execute query 
		$result = mysql_query($sql);
	}
}
// End pingSummary function

// Start kill function	
function parse_kill($obj) {
	
	# Only process plane kills/deaths, not turrets
	if ($obj->source == "plane") {
	
		# Check victim is a live player
		$sql_victim = "
			SELECT 
				* 
			FROM 
				server_players 
			WHERE 
				p_port='" .$obj->port. "' 
			AND 
				p_id='" .$obj->victim. "' 
			LIMIT 1
		";
		
		$v_query = mysql_query($sql_victim);
		# Victim result
		$v_num_rows = mysql_num_rows($v_query);
	
		# Check killer is a live player
		$sql_killer = "
			SELECT 
				* 
			FROM 
				server_players 
			WHERE 
				p_port='" .$obj->port. "' 
			AND 
				p_id='" .$obj->player. "' 
			LIMIT 1
		";


		$k_query = mysql_query($sql_killer);

	        # Killer result
		$k_num_rows = mysql_num_rows($k_query);
	
		if ($v_num_rows) {
			
			# Victim exists, process death as a crash if killer = -1
			if ($obj->player == "-1") {

				# Debug output
				if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " player crash \n"; }
	
				while ($row = mysql_fetch_assoc($v_query)) {	
				
					# Get players current crashes add 1
					$c_count = $row["p_crashes"];
					$c_count++;
					
					$sc_count = $row["s_crashes"];
					$sc_count++;

					$sql = "
						UPDATE 
							server_players 
						SET 
							p_crashes='" .$c_count. "',
							s_crashes='" .$sc_count. "'
						WHERE 
							p_port='" .$obj->port. "' 
						AND 
							p_id='" .$obj->victim. "'
					";
					
					# Execute query
					$result = mysql_query($sql);
				}

			} else {
				
				# Wasnt a crash, make sure killer is active player and not a bot
				if ($k_num_rows) {
				
					# Debug output
					if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " player kill \n"; }
	
					while ($row = mysql_fetch_assoc($v_query)) {
			
						# Get victims current deaths add 1
	                        		$d_count = $row["p_deaths"];
	                                	$d_count++;

						$ds_count = $row["s_deaths"];
                                        	$ds_count++;
	
	                                	$sql = "
							UPDATE 
								server_players 
							SET 
								p_deaths='" .$d_count. "',
								s_deaths='" .$ds_count. "'
							WHERE 
								p_port='" .$obj->port. "' 
							AND 
								p_id='" .$obj->victim. "'
						";
	                                        	
						# Execute query
						$result = mysql_query($sql);
					}
						 
					while ($row = mysql_fetch_assoc($k_query)) {

						# Get killers current kills add 1
	                        		$k_count = $row["p_kills"];
	                                	$k_count++;

                                                $ks_count = $row["s_kills"];
                                                $ks_count++;

						$sql = "
							UPDATE 
								server_players 
							SET 
								p_kills='" .$k_count. "',
								s_kills='" .$ks_count. "',
								p_streak='" .$obj->streak. "' 
							WHERE 
								p_port='" .$obj->port. "' 
							AND 
								p_id='" .$obj->player. "'
						";
	                                
						$result = mysql_query($sql);
	                        	}
				}
			}	
		}
	}
}	
// End kill function

// Start goal function
function parse_goal($obj) {
	
	$sql = "
		SELECT
			*
		FROM
			server_players
		WHERE
			p_port='" .$obj->port. "' 
		AND 
			p_id='" .$obj->player. "'
		LIMIT 1
	";

	
	$query = mysql_query($sql);
        $num_rows = mysql_num_rows($query);

	if ($num_rows) {
		if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " goal \n"; }

		while ($row = mysql_fetch_assoc($query)) {
                	$g_count = $row["p_goals"];
                        $g_count++;

			$sg_count = $row["s_goals"];
                        $sg_count++;

			
			$sql = "
				UPDATE
					server_players
				SET
					p_goals='" .$g_count. "',
					s_goals='" .$sg_count. "'
				WHERE
					p_port='" .$obj->port. "'
				AND
					p_id='" .$obj->player. "'
			";
               
		         $result = mysql_query($sql);
                }
	}
}
// End goal function

// Start spawn function
function parse_spawn($obj) {
	
	$sql = "
		SELECT
			*
		FROM
			server_players
		WHERE
			p_port='" .$obj->port. "'
		AND
			p_id='" .$obj->player. "'
		LIMIT 1
	";

	$query = mysql_query($sql);
        $num_rows = mysql_num_rows($query);

	if ($num_rows) {
	
		if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " player spawn \n"; }
	
		$isrestricted = false;	
		foreach ($GLOBALS['restricted'] as $r1) {
			if ("$obj->port"=="$r1[0]" && "$obj->plane"=="$r1[1]" && "$obj->perkRed"=="$r1[2]" && "$obj->perkGreen"=="$r1[3]" && "$obj->perkBlue"=="$r1[4]") { $isrestricted = true; }
		}
		
		if ($isrestricted) {
	
		# Plane buildout is restricted, put them in spec.
	
		 if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " player $obj->player spectated for restricted setup. \n"; }

			while ($row = mysql_fetch_assoc($query)) {
				send_command("$obj->port,console,serverWhisper \"" . addslashes($row['p_nickname']) . "\" Your plane setup is currently restricted on this server, please change your setup and spawn again.");
				send_command("$obj->port,console,serverWhisper \"" . addslashes($row['p_nickname']) . "\" For a list of restricted setups on this server, type !restricted");

				send_command("$obj->port,console,assignTeam \"" . addslashes($row['p_nickname']) . "\" -1");	
			}

		} else {

	
			while ($row = mysql_fetch_assoc($query)) {
				
				$sql = "
					UPDATE
						server_players
					SET
						p_team='" .$obj->team. "',
						p_plane='" .$obj->plane. "',
						p_perkred='" .$obj->perkRed. "',
						p_perkgreen='" .$obj->perkGreen. "',
						p_perkblue='" .$obj->perkBlue. "',
						p_skin='" .$obj->skin. "',
						p_streak='0'
					WHERE
						p_port='" .$obj->port. "'
					AND
						p_id='" .$obj->player. "'
				";
	
				$result = mysql_query($sql); 
		
			}
		}
	}	
}
// End span function

// Start teamchange function
function parse_teamchange($obj) {
	$sql = "
		SELECT
			*
		FROM
			server_players
		WHERE
			p_port='" .$obj->port. "'
		AND
			p_id='" .$obj->player. "'
		LIMIT 1
	";

	$query = mysql_query($sql);
        $num_rows = mysql_num_rows($query);

        if ($num_rows) {
		
		if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " player " .$obj->player. " teamchange to " .$obj->team. " \n"; }

		$sql = "
			UPDATE
				server_players
			SET
				p_team='" .$obj->team. "'
			WHERE
				p_port='" .$obj->port. "'
			AND
				p_id='" .$obj->player. "'
		";
		
		$result = mysql_query($sql);
	}
}
// End teamchange function

// Start structuredamage function
function parse_structuredamage($obj) {
	
	$sql = "
		SELECT
			*
		FROM
			server_players
		WHERE
			p_port='" .$obj->port. "'
		AND
			p_id='" .$obj->player. "'
		LIMIT 1
	";
	
	$query = mysql_query($sql);
	$num_rows = mysql_num_rows($query);

  	if ($num_rows) {
        	
		if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " basedamage " .$obj->player. " \n"; }
			
	        while ($row = mysql_fetch_assoc($query)) {
                
			$d_count = $row["p_structuredamage"];
                        $t_count = $d_count + $obj->xp;

			$sd_count = $row["s_structuredamage"];
                        $st_count = $sd_count + $obj->xp;

			$sql = "
				UPDATE
					server_players
				SET
					p_structuredamage='" .$t_count. "',
					s_structuredamage='" .$st_count. "'
				WHERE
					p_port='" .$obj->port. "'
				AND
					p_id='" .$obj->player. "'
			";

                        $result = mysql_query($sql);
                }
 	}
}
// End structuredamage function

// Start assist function
function parse_assist($obj) {
	
	$sql = "
		SELECT
			*
		FROM
			server_players
		WHERE
			p_port='" .$obj->port. "'
		AND
			p_id='" .$obj->player. "'
		LIMIT 1
	";
	
	$query = mysql_query($sql);
        $num_rows = mysql_num_rows($query);

        if ($num_rows) {
	
        	if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " assist \n"; }
		
		
		$v_sql = " 
                        SELECT
                                *
                        FROM
                                server_players
                        WHERE
                                p_port='" .$obj->port. "'
                        AND
                                p_id='" .$obj->victim. "'
                        LIMIT 1
		";

		$v_query = mysql_query($v_sql);
 		$v_num_rows = mysql_num_rows($v_query);
			
		if ($v_num_rows) {
                         while ($row = mysql_fetch_assoc($query)) {
                         	$a_count = $row["p_assists"];
                         	$a_count++;
	
				$sa_count = $row["s_assists"];
                                $sa_count++;

				$p_sql = "
					UPDATE
						server_players
					SET
						p_assists='" .$a_count. "',
						s_assists='" .$sa_count. "'
					WHERE 
						p_port='" .$obj->port. "' 
					AND 
						p_id='" .$obj->player. "'
				";
                         	
				$result = mysql_query($p_sql);
                         } 
		}
	}
}
// End assist function

// Start chat function
function parse_chat($obj) {

	# Debug output
	if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " chat from " .$obj->player. " -- " .$obj->message. "  \n"; }

	if (!$obj->server)
	{
		# Query player information
		$p_sql = "
			SELECT 
				*
			FROM
				server_players
			WHERE
				p_port='" .$obj->port. "'
			AND
				p_id='" .$obj->player. "'
			LIMIT 1
                ";

		$p_query = mysql_query($p_sql);
		$p_num_rows = mysql_num_rows($p_query);


		# Query server information
                $s_sql = "
                        SELECT
                                *
                        FROM
                                server_status
                        WHERE
                                port='" .$obj->port. "'
                        LIMIT 1
                ";
		
		$s_query = mysql_query($s_sql);
		$s_num_rows = mysql_num_rows($s_query);
		
		
		while ($row = mysql_fetch_assoc($p_query)) {
			
			// Process here

			
			// Start !help
			if ($obj->message == "!help") { 
			send_command("$obj->port,console,serverWhisper \"" . addslashes($row['p_nickname']) . "\" Available commands: !restricted, !session, !tournament");
			} 
			// End !help


			// Start !restricted
                        if ($obj->message == "!restricted") {
                        	send_command("$obj->port,console,serverWhisper \"" . addslashes($row['p_nickname']) . "\" Restricted setups for this server are:");
					
				$a = 1;	
	                	foreach ($GLOBALS['restricted'] as $r1) {
                       
					if ("$obj->port"=="$r1[0]") {
			 		send_command("$obj->port,console,serverWhisper \"" . addslashes($row['p_nickname']) . "\" Restricted $a: $r1[1], $r1[2], $r1[3], $r1[4] ");
					$a++;
	                		}
				}
			


	
                        } 
			// End !restricted

			// Start !session
			if ($obj->message == "!session") {
			

			        # Query player information
                		$sql = "
                        		SELECT
                                		*
                        		FROM
                                		server_players
                        		WHERE
                                		p_id='" .$obj->player. "'		
					AND
						p_port='" .$obj->port. "'
                        		LIMIT 1
                		";
	
        		        $query = mysql_query($sql);
				$num_rows = mysql_num_rows($query);

				if ($num_rows) {
		                	while ($row = mysql_fetch_assoc($query)) {
	
						$pts = time() - $row['p_time']; 
				 		send_command("$obj->port,console,serverWhisper \"" . addslashes($row['p_nickname']) . "\" Statistics for your current session (" .duration($pts) . "):");
						send_command("$obj->port,console,serverWhisper \"" . addslashes($row['p_nickname']) . "\" Kills: " .$row['s_kills']. ", Deaths: " .$row['s_deaths']. ", Assists: " .$row['s_assists']. ", Crashes: " .$row['s_crashes']. ", Goals: " .$row['s_goals']. ", StructureDamage: " .$row['s_structuredamage']. " "); 
					}
                        	}
			}
			// End !session

			// Start !torunament
			if ($obj->message == "!tournament") {
				if (in_array($obj->port, $GLOBALS['tservers'])) {
					send_command("$obj->port,console,serverMessage Attempting to start tournament, please hold..");
			
					while ($srow = mysql_fetch_assoc($s_query)) {
				
						if ($srow['map'] != "tbd_palp") {
							send_command("$obj->port,console,serverMessage Please switch to the correct map before starting tournament.");
						} else {
							$sql = "
								SELECT
									*
								FROM
									server_players
								WHERE

									p_team > 2
								AND
									p_port='" .$obj->port. "'
							";
				
							$query = mysql_query($sql);
							$num_rows = mysql_num_rows($query);
					
							if ($num_rows == 0) {

								send_command("$obj->port,console,serverMessage There is currently nobody in the game.  Please join the game and try again.");

							} else {
						
								if (is_odd($num_rows)) {
						
									send_command("$obj->port,console,serverMessage There are " . $num_rows . " players ready, this server requires " .$GLOBALS['tmin']. " players to begin.");	
								} else {
							
									$trand = array_rand($GLOBALS['tmaps'],1);
									send_command("$obj->port,console,serverMessage Check complete, tournament beginning.");
									send_command("$obj->port,console,startTournament");
									send_command("$obj->port,console,changeMap " . $GLOBALS['tmaps'][$trand]);
								}
							}

						}
						
					} // End long while
				} else {
					send_command("$obj->port,console,serverMessage Tournament mode is not enabled on this server.");	

					# send_command("$obj->port,console,startTournament");
					# send_command("$obj->port,console,changeMap tbd_core");
			
				} // End !tournament else
			} // End !tournament		

		}
	}
}
// End chat function

// Start tournamentroundend function
function parse_tournamentroundend($obj) {
	send_command("$obj->port,console,stopTournament");
	send_command("$obj->port,console,serverMessage Tournament finished, thanks for playing.");
}
// End tournamentroundend function

function parse_clientnicknamechange($obj) {

	# Debug output
        if ($GLOBALS['debug']) { echo "PALP: Parsing " .$obj->port. " User namechange: " .$obj->oldNickname. " is now " .$obj->newNickname. "\n"; }

	$sql = "
       	UPDATE
		server_players
	SET
		p_nickname='" .mysql_real_escape_string($obj->newNickname). "'
	WHERE
		p_port='" .$obj->port. "'
	AND
		p_vaporid='" .$obj->vaporId. "'
";

	$result = mysql_query($sql);

}

// Start command function
function send_command($command) {
	echo "Sending command " .$command. "\n";
	$cf = fopen($GLOBALS['commandfile'], "a");
	fwrite($cf, "$command\n");
	fclose($cf);
}
// End command function

//=========================== Main ==================================

# Starting announcement
echo "PALP: Starting..\n";

# Establish database connection
$dblink = mysql_connect($GLOBALS['mysqlhost'],$GLOBALS['mysqluser'],$GLOBALS['mysqlpass']);
if (!$dblink) {
	die('Error: ' . mysql_error());
}

# Select mysql DB
$dbselect = mysql_select_db($GLOBALS['mysqldb'], $dblink);
if (!$dbselect) {
	die ('Error: ' . mysql_error());
}

# Announce DB connection
echo "PALP: Database connection established successfully\n";

# Set tail arguments
$fp = popen("tail -n 0 -F " .$logfile. " 2>&1", "rb");
if (!$fp) {
	die ('Error: Could not open' .$logfile. ', please check your settings.');
}

# Announce file location
echo "PALP: Parsing " .$logfile. "\n";

# Stream tail output
while (!feof($fp))
{	
	# Still testing byte value, 1024 seems to work best
	$json = fgets($fp);

	# Remove trailing commas and ensure utf8
	$obj = mjson_decode($json);

	# Primary statement
        if ($obj->type) {
                if ($obj->type == "mapChange") { parse_mapchange($obj); }
                if ($obj->type == "clientAdd") { parse_clientadd($obj); }
                if ($obj->type == "clientRemove") { parse_clientremove($obj); }
                if ($obj->type == "spawn") { parse_spawn($obj); }
                if ($obj->type == "kill") { parse_kill($obj); }
                if ($obj->type == "pingSummary") { parse_pingsummary($obj); }
                if ($obj->type == "goal") { parse_goal($obj); }
                if ($obj->type == "teamChange") { parse_teamchange($obj); }
                if ($obj->type == "structureDamage") { parse_structuredamage($obj); }
                if ($obj->type == "assist") { parse_assist($obj); }
                if ($obj->type == "serverInit") { parse_serverinit($obj); }
                if ($obj->type == "chat") { parse_chat($obj); }
		if ($obj->type == "tournamentRoundEnd") { parse_tournamentroundend($obj); }
		if ($obj->type == "clientNicknameChange") { parse_clientnicknamechange($obj); }
        }
}

// Close connections

pclose($fp);	

mysql_close($mysql);

?>
